@@ -1,5 +1,5 @@
 /*****************************************************************************
- * dictcore.cpp - QStarDict, a StarDict clone written with using Qt          *
+ * dictcore.cpp - QStarDict, a StarDict clone written using Qt               *
  * Copyright (C) 2008 Alexander Rodin                                        *
  *                                                                           *
  * This program is free software; you can redistribute it and/or modify      *
@@ -27,7 +27,7 @@
 #include <QSettings>
 #include <QDebug>
 #include <QPluginLoader>
-#include "dictplugin.h"
+#include "../plugins/dictplugin.h"
 
 namespace QStarDict
 {
@@ -102,16 +102,28 @@ QStringList DictCore::findSimilarWords(const QString &word)
 QStringList DictCore::availablePlugins() const
 {
     QStringList result;
-#ifdef Q_OS_UNIX
+#ifdef Q_WS_X11
     QFileInfoList files = QDir(QSTARDICT_PLUGINS_DIR).entryInfoList(QStringList("lib*.so"),
                   QDir::Files | QDir::NoDotAndDotDot);
     for (QFileInfoList::const_iterator i = files.begin(); i != files.end(); ++i)
         result << i->fileName().mid(3, i->fileName().length() - 6);
-#elif defined Q_OS_WIN
+#elif defined Q_WS_WIN
     QFileInfoList files = QDir(QSTARDICT_PLUGINS_DIR).entryInfoList(QStringList("*0.dll"),
                   QDir::Files | QDir::NoDotAndDotDot);
     for (QFileInfoList::const_iterator i = files.begin(); i != files.end(); ++i)
         result << i->fileName().left(i->fileName().length() - 5);
+#elif defined Q_WS_MAC
+    QStringList macFilters;
+    // various Qt versions...
+    macFilters << "*.dylib" << "*.bundle" << "*.so";
+    QString binPath = QCoreApplication::applicationDirPath();
+    // navigate through mac's bundle tree structore
+    QDir d(binPath + "/../lib/");
+    QFileInfoList files = d.entryInfoList(macFilters,
+                                          QDir::Files | QDir::NoDotAndDotDot);
+    for (QFileInfoList::const_iterator i = files.begin(); i != files.end(); ++i) {
+        result << i->fileName();
+    }
 #else
 #error "Function DictCore::availablePlugins() is not implemented on this platform"
 #endif
@@ -129,11 +141,13 @@ void DictCore::setLoadedPlugins(const QStringList &loadedPlugins)
 
     for (QStringList::const_iterator i = loadedPlugins.begin(); i != loadedPlugins.end(); ++i)
     {
-#ifdef Q_OS_UNIX
+#ifdef Q_WS_X11
         QString pluginFilename = static_cast<QString>(QSTARDICT_PLUGINS_DIR) + "/" "lib" + *i + ".so";
-#elif defined Q_OS_WIN
-        // TODO
+#elif defined Q_WS_WIN
         QString pluginFilename = static_cast<QString>(QSTARDICT_PLUGINS_DIR) + "/" + *i + "0.dll";
+#elif defined Q_WS_MAC
+        // here we need to follow mac's bundle tree...
+        QString pluginFilename = QDir(QCoreApplication::applicationDirPath()+"/../lib/"+*i).absolutePath();
 #else
 #error "Function DictCore::setLoadedPlugins(const QStringList &loadedPlugins) is not available on this platform"
 #endif
